/**
 * Api collection resource
 * Api collection resource
 */
export interface ApiCollectionResource {
    /**
     * Links for pagination
     */
    links?: {
        /**
         * Link to first page
         */
        first: string;
        /**
         * Link to last page
         */
        last: string;
        /**
         * Link to next page
         */
        next: string;
        /**
         * Link to previous page
         */
        prev: string;
    };
    /**
     * Meta information about data
     */
    meta?: {
        /**
         * Current page
         */
        current_page: number;
        /**
         * First item no.
         */
        from: number;
        /**
         * Last page number
         */
        last_page: number;
        /**
         * Path to resource collection
         */
        path: string;
        /**
         * Per page items
         */
        per_page: number;
        /**
         * Last item no.
         */
        to: number;
        /**
         * Total items
         */
        total: string;
    };
}
/**
 * App Update Required
 * Result if app needs to be updated
 * example:
 * [object Object]
 */
export declare type AppUpdateRequired = any;
/**
 * Article model
 * Resource based on Article model
 * example:
 * [object Object]
 */
export interface Article {
    /**
     * Article Category Id
     */
    article_category_id: number;
    banners: BannerMinimal[];
    /**
     * Body
     */
    body?: string;
    /**
     * Created At
     */
    created_at?: string;
    /**
     * Id
     */
    id: number;
    images: {
        cover?: Image;
        detail?: Image;
    };
    meta_data?: MetaData;
    /**
     * Perex
     */
    perex?: string;
    /**
     * Published At
     */
    published_at?: string;
    /**
     * Show in app slider
     */
    show_in_app_slider: boolean;
    /**
     * Show on dashboard
     */
    show_on_dashboard: boolean;
    /**
     * Slug
     */
    slug?: string;
    tags: Tag[];
    /**
     * Title
     */
    title?: string;
    /**
     * Updated At
     */
    updated_at?: string;
}
/**
 * Article Category model
 * Resource based on Article Category model
 * example:
 * [object Object]
 */
export interface ArticleCategory {
    /**
     * Color
     */
    color: "default" | "primary" | "info" | "turquoise";
    /**
     * Created At
     */
    created_at?: string;
    /**
     * Id
     */
    id: number;
    /**
     * Published At
     */
    published_at?: string;
    /**
     * Slug
     */
    slug?: string;
    /**
     * Title
     */
    title?: string;
    /**
     * Updated At
     */
    updated_at?: string;
}
/**
 * Api collection resource
 * Api collection resource
 * example:
 * [object Object]
 */
export interface ArticleCategoryCollection {
    /**
     * Links for pagination
     */
    links: {
        /**
         * Link to first page
         */
        first: string;
        /**
         * Link to last page
         */
        last: string;
        /**
         * Link to next page
         */
        next: string;
        /**
         * Link to previous page
         */
        prev: string;
    };
    /**
     * Meta information about data
     */
    meta: {
        /**
         * Current page
         */
        current_page: number;
        /**
         * First item no.
         */
        from: number;
        /**
         * Last page number
         */
        last_page: number;
        /**
         * Path to resource collection
         */
        path: string;
        /**
         * Per page items
         */
        per_page: number;
        /**
         * Last item no.
         */
        to: number;
        /**
         * Total items
         */
        total: string;
    };
    /**
     * Data of the resource collection
     */
    data: ArticleCategory[];
}
/**
 * Api collection resource
 * Api collection resource
 * example:
 * [object Object]
 */
export interface ArticleCollection {
    /**
     * Links for pagination
     */
    links: {
        /**
         * Link to first page
         */
        first: string;
        /**
         * Link to last page
         */
        last: string;
        /**
         * Link to next page
         */
        next: string;
        /**
         * Link to previous page
         */
        prev: string;
    };
    /**
     * Meta information about data
     */
    meta: {
        /**
         * Current page
         */
        current_page: number;
        /**
         * First item no.
         */
        from: number;
        /**
         * Last page number
         */
        last_page: number;
        /**
         * Path to resource collection
         */
        path: string;
        /**
         * Per page items
         */
        per_page: number;
        /**
         * Last item no.
         */
        to: number;
        /**
         * Total items
         */
        total: string;
    };
    /**
     * Data of the resource collection
     */
    data: Article[];
}
/**
 * Banner model
 * Resource based on Banner model
 * example:
 * [object Object]
 */
export interface Banner {
    /**
     * App Types
     */
    app_types: ("web" | "mobile")[];
    /**
     * Created At
     */
    created_at?: string;
    /**
     * Id
     */
    id: number;
    images: {
        background?: Image;
        icon?: Image;
        image?: Image;
    };
    /**
     * Layout
     */
    layout: "dashboard-white-with-ico" | "dashboard-with-turquoise-background" | "dashboard-with-turquoise-overlay" | "article";
    /**
     * Link  New Window
     */
    link_new_window: boolean;
    /**
     * Link Text
     */
    link_text?: string;
    /**
     * Link Url
     */
    link_url?: string;
    /**
     * Perex
     */
    perex?: string;
    /**
     * Published At
     */
    published_at?: string;
    /**
     * Show On Dashboard
     */
    show_on_dashboard: boolean;
    /**
     * Title
     */
    title?: string;
    /**
     * Updated At
     */
    updated_at?: string;
}
/**
 * Api collection resource
 * Api collection resource
 * example:
 * [object Object]
 */
export interface BannerCollection {
    /**
     * Links for pagination
     */
    links: {
        /**
         * Link to first page
         */
        first: string;
        /**
         * Link to last page
         */
        last: string;
        /**
         * Link to next page
         */
        next: string;
        /**
         * Link to previous page
         */
        prev: string;
    };
    /**
     * Meta information about data
     */
    meta: {
        /**
         * Current page
         */
        current_page: number;
        /**
         * First item no.
         */
        from: number;
        /**
         * Last page number
         */
        last_page: number;
        /**
         * Path to resource collection
         */
        path: string;
        /**
         * Per page items
         */
        per_page: number;
        /**
         * Last item no.
         */
        to: number;
        /**
         * Total items
         */
        total: string;
    };
    /**
     * Data of the resource collection
     */
    data: Banner[];
}
/**
 * Banner minimal model
 * Minimal resource for Banner model
 * example:
 * [object Object]
 */
export interface BannerMinimal {
    /**
     * Id
     */
    id: number;
    /**
     * Resource Url
     */
    resource_url: string;
}
/**
 * Faq model
 * Resource based on Faq model
 * example:
 * [object Object]
 */
export interface Faq {
    /**
     * Answer
     */
    answer?: string;
    /**
     * Created At
     */
    created_at?: string;
    /**
     * Id
     */
    id: number;
    meta_data?: MetaData;
    /**
     * Published At
     */
    published_at?: string;
    /**
     * Question
     */
    question?: string;
    /**
     * Updated At
     */
    updated_at?: string;
}
/**
 * Api collection resource
 * Api collection resource
 * example:
 * [object Object]
 */
export interface FaqCollection {
    /**
     * Links for pagination
     */
    links: {
        /**
         * Link to first page
         */
        first: string;
        /**
         * Link to last page
         */
        last: string;
        /**
         * Link to next page
         */
        next: string;
        /**
         * Link to previous page
         */
        prev: string;
    };
    /**
     * Meta information about data
     */
    meta: {
        /**
         * Current page
         */
        current_page: number;
        /**
         * First item no.
         */
        from: number;
        /**
         * Last page number
         */
        last_page: number;
        /**
         * Path to resource collection
         */
        path: string;
        /**
         * Per page items
         */
        per_page: number;
        /**
         * Last item no.
         */
        to: number;
        /**
         * Total items
         */
        total: string;
    };
    /**
     * Data of the resource collection
     */
    data: Faq[];
}
/**
 * Forbidden error response
 * example:
 * [object Object]
 */
export interface Forbidden {
    /**
     * Error message
     */
    message?: any;
}
/**
 * Frontend translate model
 * Resource based on Frontend translate model
 * example:
 * [object Object]
 */
export interface FrontendTranslation {
    /**
     * Key
     */
    key: string;
    /**
     * Array of references
     */
    references?: string[][];
    /**
     * Translation in requested language
     */
    translation?: string;
}
/**
 * Api collection resource
 * Api collection resource
 * example:
 * [object Object]
 */
export interface FrontendTranslationCollection {
    /**
     * Links for pagination
     */
    links: {
        /**
         * Link to first page
         */
        first: string;
        /**
         * Link to last page
         */
        last: string;
        /**
         * Link to next page
         */
        next: string;
        /**
         * Link to previous page
         */
        prev: string;
    };
    /**
     * Meta information about data
     */
    meta: {
        /**
         * Current page
         */
        current_page: number;
        /**
         * First item no.
         */
        from: number;
        /**
         * Last page number
         */
        last_page: number;
        /**
         * Path to resource collection
         */
        path: string;
        /**
         * Per page items
         */
        per_page: number;
        /**
         * Last item no.
         */
        to: number;
        /**
         * Total items
         */
        total: string;
    };
    /**
     * Data of the resource collection
     */
    data: FrontendTranslation[];
}
/**
 * Frontend translation file input data
 * Frontend translation file data
 */
export declare type FrontendTranslationFileInput = any;
/**
 * Frontend translation input data
 * Frontend translation input data model
 * example:
 * [object Object]
 */
export interface FrontendTranslationInput {
    app_type?: "web" | "mobile";
    /**
     * Json with translations in key: value format
     */
    translations: string;
}
/**
 * Hint model
 * Resource based on Hint model
 * example:
 * [object Object]
 */
export interface Hint {
    /**
     * Created At
     */
    created_at?: string;
    /**
     * Id
     */
    id: number;
    /**
     * Link New Window
     */
    link_new_window: boolean;
    /**
     * Link Text
     */
    link_text?: string;
    /**
     * Link Url
     */
    link_url?: string;
    /**
     * Published At
     */
    published_at?: string;
    /**
     * Text
     */
    text?: string;
    /**
     * Type
     */
    type: string;
    /**
     * Updated At
     */
    updated_at?: string;
}
/**
 * Api collection resource
 * Api collection resource
 * example:
 * [object Object]
 */
export interface HintCollection {
    /**
     * Links for pagination
     */
    links: {
        /**
         * Link to first page
         */
        first: string;
        /**
         * Link to last page
         */
        last: string;
        /**
         * Link to next page
         */
        next: string;
        /**
         * Link to previous page
         */
        prev: string;
    };
    /**
     * Meta information about data
     */
    meta: {
        /**
         * Current page
         */
        current_page: number;
        /**
         * First item no.
         */
        from: number;
        /**
         * Last page number
         */
        last_page: number;
        /**
         * Path to resource collection
         */
        path: string;
        /**
         * Per page items
         */
        per_page: number;
        /**
         * Last item no.
         */
        to: number;
        /**
         * Total items
         */
        total: string;
    };
    /**
     * Data of the resource collection
     */
    data: Hint[];
}
/**
 * Image type format
 */
export interface Image {
    /**
     * Standard size image url
     */
    "1x"?: any;
    /**
     * 2x size image url
     */
    "2x"?: any;
    /**
     * Collection name
     */
    collection_name?: any;
}
/**
 * Inquiry input data
 * Inquiry input data model
 * example:
 * [object Object]
 */
export interface InquiryInput {
    /**
     * Body
     */
    body: string;
    /**
     * Email
     */
    email: string;
    /**
     * Recaptcha response
     */
    "g-recaptcha-response"?: string;
    /**
     * Subject
     */
    subject: string;
    /**
     * Targets
     */
    targets: string[];
}
/**
 * Locale in which the response is sent
 */
export declare type Locale = "sk" | "en";
/**
 * MetaData model
 * Resource based on MetaData model
 * example:
 * [object Object]
 */
export interface MetaData {
    /**
     * Id
     */
    id: number;
    /**
     * Meta Description
     */
    meta_description?: string;
    /**
     * Meta Title
     */
    meta_title?: string;
    /**
     * Og Description
     */
    og_description?: string;
    /**
     * Og Image
     */
    og_image?: string;
    /**
     * Og Title
     */
    og_title?: string;
    /**
     * Og Type
     */
    og_type?: string;
    /**
     * Og Url
     */
    og_url?: string;
}
/**
 * Not Found
 * example:
 * [object Object]
 */
export interface NotFound {
    /**
     * Error message
     */
    message?: any;
}
/**
 * Notification model
 * Resource based on Notification model
 * example:
 * [object Object]
 */
export interface Notification {
    /**
     * App Types
     */
    app_types: ("web" | "mobile")[];
    /**
     * Created At
     */
    created_at?: string;
    /**
     * Id
     */
    id: number;
    /**
     * Perex
     */
    perex?: string;
    /**
     * Published At
     */
    published_at?: string;
    /**
     * Text
     */
    text?: string;
    /**
     * Title
     */
    title?: string;
    /**
     * Updated At
     */
    updated_at?: string;
}
/**
 * Api collection resource
 * Api collection resource
 * example:
 * [object Object]
 */
export interface NotificationCollection {
    /**
     * Links for pagination
     */
    links: {
        /**
         * Link to first page
         */
        first: string;
        /**
         * Link to last page
         */
        last: string;
        /**
         * Link to next page
         */
        next: string;
        /**
         * Link to previous page
         */
        prev: string;
    };
    /**
     * Meta information about data
     */
    meta: {
        /**
         * Current page
         */
        current_page: number;
        /**
         * First item no.
         */
        from: number;
        /**
         * Last page number
         */
        last_page: number;
        /**
         * Path to resource collection
         */
        path: string;
        /**
         * Per page items
         */
        per_page: number;
        /**
         * Last item no.
         */
        to: number;
        /**
         * Total items
         */
        total: string;
    };
    /**
     * Data of the resource collection
     */
    data: Notification[];
}
/**
 * Product model
 * Resource based on Product model
 * example:
 * [object Object]
 */
export interface Product {
    /**
     * Acceptance text
     */
    acceptance_text?: string;
    /**
     * Box 1 button new window
     */
    box_1_button_new_window?: boolean;
    /**
     * Box 1 button text
     */
    box_1_button_text?: string;
    /**
     * Box 1 button url
     */
    box_1_button_url?: string;
    /**
     * Box 1 perex
     */
    box_1_perex?: string;
    /**
     * Box 1 title
     */
    box_1_title?: string;
    /**
     * Box 2 button 1 new window
     */
    box_2_button_1_new_window?: boolean;
    /**
     * Box 2 button 1 text
     */
    box_2_button_1_text?: string;
    /**
     * Box 2 button 1 url
     */
    box_2_button_1_url?: string;
    /**
     * Box 2 button 2 new window
     */
    box_2_button_2_new_window?: boolean;
    /**
     * Box 2 button 2 text
     */
    box_2_button_2_text?: string;
    /**
     * Box 2 button 2 url
     */
    box_2_button_2_url?: string;
    /**
     * Box 2 perex
     */
    box_2_perex?: string;
    /**
     * Box 2 title
     */
    box_2_title?: string;
    /**
     * Created At
     */
    created_at?: string;
    /**
     * Id
     */
    id: number;
    images: {
        box_1_background?: Image;
        box_2_background?: Image;
        icon?: Image;
    };
    /**
     * Layout
     */
    layout?: string;
    /**
     * Products for acceptance
     */
    products?: ProductAcceptance[];
    /**
     * Published At
     */
    published_at?: string;
    /**
     * Slug
     */
    slug?: string;
    /**
     * Text between boxes
     */
    text_between_boxes?: string;
    /**
     * Title
     */
    title?: string;
    /**
     * Up Id
     */
    up_id?: number;
    /**
     * Updated At
     */
    updated_at?: string;
}
/**
 * Product acceptance model
 * Acceptance resource based on Product model
 * example:
 * [object Object]
 */
export interface ProductAcceptance {
    /**
     * Acceptance text
     */
    acceptance_text?: string;
    /**
     * Created At
     */
    created_at?: string;
    /**
     * Id
     */
    id: number;
    images: {
        icon?: Image;
    };
    /**
     * Published At
     */
    published_at?: string;
    /**
     * Slug
     */
    slug?: string;
    /**
     * Title
     */
    title?: string;
    /**
     * Updated At
     */
    updated_at?: string;
}
/**
 * Api collection resource
 * Api collection resource
 * example:
 * [object Object]
 */
export interface ProductCollection {
    /**
     * Links for pagination
     */
    links: {
        /**
         * Link to first page
         */
        first: string;
        /**
         * Link to last page
         */
        last: string;
        /**
         * Link to next page
         */
        next: string;
        /**
         * Link to previous page
         */
        prev: string;
    };
    /**
     * Meta information about data
     */
    meta: {
        /**
         * Current page
         */
        current_page: number;
        /**
         * First item no.
         */
        from: number;
        /**
         * Last page number
         */
        last_page: number;
        /**
         * Path to resource collection
         */
        path: string;
        /**
         * Per page items
         */
        per_page: number;
        /**
         * Last item no.
         */
        to: number;
        /**
         * Total items
         */
        total: string;
    };
    /**
     * Data of the resource collection
     */
    data: Product[];
}
/**
 * Product Main Category model
 * Resource based on Product Main Category model
 * example:
 * [object Object]
 */
export interface ProductMainCategory {
    /**
     * Created At
     */
    created_at?: string;
    /**
     * Id
     */
    id: number;
    products?: ProductMinimal[];
    /**
     * Published At
     */
    published_at?: string;
    /**
     * Title
     */
    title?: string;
    /**
     * Updated At
     */
    updated_at?: string;
}
/**
 * Api collection resource
 * Api collection resource
 * example:
 * [object Object]
 */
export interface ProductMainCategoryCollection {
    /**
     * Links for pagination
     */
    links: {
        /**
         * Link to first page
         */
        first: string;
        /**
         * Link to last page
         */
        last: string;
        /**
         * Link to next page
         */
        next: string;
        /**
         * Link to previous page
         */
        prev: string;
    };
    /**
     * Meta information about data
     */
    meta: {
        /**
         * Current page
         */
        current_page: number;
        /**
         * First item no.
         */
        from: number;
        /**
         * Last page number
         */
        last_page: number;
        /**
         * Path to resource collection
         */
        path: string;
        /**
         * Per page items
         */
        per_page: number;
        /**
         * Last item no.
         */
        to: number;
        /**
         * Total items
         */
        total: string;
    };
    /**
     * Data of the resource collection
     */
    data: ProductMainCategory[];
}
/**
 * Product minimal model
 * Minimal resource based on Product model
 * example:
 * [object Object]
 */
export interface ProductMinimal {
    /**
     * Id
     */
    id: number;
    /**
     * Slug
     */
    slug?: string;
    /**
     * Title
     */
    title?: string;
}
/**
 * Product Thematic Category model
 * Resource based on Product Thematic Category model
 * example:
 * [object Object]
 */
export interface ProductThematicCategory {
    /**
     * Created At
     */
    created_at?: string;
    /**
     * Id
     */
    id: number;
    /**
     * Perex
     */
    perex?: string;
    products?: ProductMinimal[];
    /**
     * Published At
     */
    published_at?: string;
    /**
     * Title
     */
    title?: string;
    /**
     * Updated At
     */
    updated_at?: string;
}
/**
 * Api collection resource
 * Api collection resource
 * example:
 * [object Object]
 */
export interface ProductThematicCategoryCollection {
    /**
     * Links for pagination
     */
    links: {
        /**
         * Link to first page
         */
        first: string;
        /**
         * Link to last page
         */
        last: string;
        /**
         * Link to next page
         */
        next: string;
        /**
         * Link to previous page
         */
        prev: string;
    };
    /**
     * Meta information about data
     */
    meta: {
        /**
         * Current page
         */
        current_page: number;
        /**
         * First item no.
         */
        from: number;
        /**
         * Last page number
         */
        last_page: number;
        /**
         * Path to resource collection
         */
        path: string;
        /**
         * Per page items
         */
        per_page: number;
        /**
         * Last item no.
         */
        to: number;
        /**
         * Total items
         */
        total: string;
    };
    /**
     * Data of the resource collection
     */
    data: ProductThematicCategory[];
}
/**
 * Special Offer model
 * Resource based on Special Offer model
 * example:
 * [object Object]
 */
export interface SpecialOffer {
    /**
     * Box 1 button new window
     */
    box_1_button_new_window?: boolean;
    /**
     * Box 1 button text
     */
    box_1_button_text?: string;
    /**
     * Box 1 button url
     */
    box_1_button_url?: string;
    /**
     * Box 1 perex
     */
    box_1_perex?: string;
    /**
     * Box 1 subtitle
     */
    box_1_subtitle?: string;
    /**
     * Box 1 title
     */
    box_1_title?: string;
    /**
     * Box 2 button 1 new window
     */
    box_2_button_1_new_window?: boolean;
    /**
     * Box 2 button 1 text
     */
    box_2_button_1_text?: string;
    /**
     * Box 2 button 1 url
     */
    box_2_button_1_url?: string;
    /**
     * Box 2 button 2 new window
     */
    box_2_button_2_new_window?: boolean;
    /**
     * Box 2 button 2 text
     */
    box_2_button_2_text?: string;
    /**
     * Box 2 button 2 url
     */
    box_2_button_2_url?: string;
    /**
     * Box 2 perex
     */
    box_2_perex?: string;
    /**
     * Box 2 title
     */
    box_2_title?: string;
    /**
     * Created At
     */
    created_at?: string;
    /**
     * Id
     */
    id: number;
    images?: {
        box_1_background?: Image;
        box_2_background?: Image;
        listing?: Image;
        qr_code?: Image;
    };
    /**
     * Layout
     */
    layout?: string;
    /**
     * Published At
     */
    published_at?: string;
    /**
     * Published To
     */
    published_to?: string;
    /**
     * Slug
     */
    slug?: string;
    /**
     * Text between boxes
     */
    text_between_boxes?: string;
    /**
     * Title
     */
    title?: string;
    /**
     * Updated At
     */
    updated_at?: string;
}
/**
 * Api collection resource
 * Api collection resource
 * example:
 * [object Object]
 */
export interface SpecialOfferCollection {
    /**
     * Links for pagination
     */
    links: {
        /**
         * Link to first page
         */
        first: string;
        /**
         * Link to last page
         */
        last: string;
        /**
         * Link to next page
         */
        next: string;
        /**
         * Link to previous page
         */
        prev: string;
    };
    /**
     * Meta information about data
     */
    meta: {
        /**
         * Current page
         */
        current_page: number;
        /**
         * First item no.
         */
        from: number;
        /**
         * Last page number
         */
        last_page: number;
        /**
         * Path to resource collection
         */
        path: string;
        /**
         * Per page items
         */
        per_page: number;
        /**
         * Last item no.
         */
        to: number;
        /**
         * Total items
         */
        total: string;
    };
    /**
     * Data of the resource collection
     */
    data: SpecialOffer[];
}
/**
 * Tag model
 * Resource based on Tag model
 * example:
 * [object Object]
 */
export interface Tag {
    /**
     * Id
     */
    id: number;
    /**
     * Title
     */
    title?: string;
}
/**
 * Unauthorized error response
 * example:
 * [object Object]
 */
export interface Unauthorized {
    /**
     * Error message
     */
    message?: any;
}
/**
 * Unprocessable Entity
 * example:
 * [object Object]
 */
export interface UnprocessableEntity {
    /**
     * Errors per field
     */
    errors?: any;
    /**
     * Error message
     */
    message?: any;
}
