export interface AccessItem {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    employee_id: string;
    /**
     * example:
     * false
     */
    is_administrator: boolean;
}
export interface AccessTokenResponse {
    access_token?: string;
    expires_in?: number;
    refresh_expires_in?: number;
    refresh_token?: string;
    token_type?: string;
    not_before_policy?: number;
    session_state?: string;
    scope?: string;
}
export interface Address {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    id: string;
    country: Country;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    merchant_request_id?: string;
    /**
     * example:
     * Name 123
     */
    name?: string;
    /**
     * example:
     * 25601
     */
    postcode?: string;
    /**
     * example:
     * Vančurova
     */
    street?: string;
    /**
     * example:
     * Benešov
     */
    city?: string;
}
export interface AddressesResponse {
    pagination: Pagination;
    data: Address[];
}
export interface Administrator {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    id: string;
    /**
     * example:
     * Jan Novak
     */
    name: string;
    /**
     * example:
     * novak@email.cz
     */
    email?: string;
    /**
     * example:
     * false
     */
    is_master: boolean;
    can_manage_addresses?: string[];
}
export interface AdministratorsResponse {
    pagination: Pagination;
    data: Administrator[];
}
export interface Affiliate {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    id: string;
    repayment_frequency: RepaymentFrequency;
    /**
     * example:
     * Name 123
     */
    name?: string;
    /**
     * example:
     * IBAN 123
     */
    iban?: string;
    /**
     * example:
     * 1.5
     */
    current_amount?: number;
    /**
     * example:
     * 2018-02-06
     */
    last_repayment_date?: string;
    /**
     * example:
     * 2018-02-06
     */
    next_repayment_date?: string;
    /**
     * example:
     * 1.5
     */
    up_partner_repayment_percentage?: number;
    /**
     * example:
     * false
     */
    allow_express: boolean;
    /**
     * example:
     * Number 123
     */
    account_number?: string;
}
export interface AffiliateAccount {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    id: string;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    affiliate_id: string;
    /**
     * example:
     * Title 123
     */
    name?: string;
    /**
     * example:
     * 1.5
     */
    amount?: number;
    /**
     * example:
     * 2018-02-06
     */
    last_repayment_date?: string;
    /**
     * example:
     * 1.5
     */
    last_repayment_amount?: number;
    /**
     * example:
     * 2018-02-06
     */
    next_repayment_date?: string;
}
export interface AffiliateDetail {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    id: string;
    repayment_frequency: RepaymentFrequency;
    /**
     * example:
     * Name 123
     */
    name?: string;
    /**
     * example:
     * IBAN 123
     */
    iban?: string;
    /**
     * example:
     * 1.5
     */
    current_amount?: number;
    /**
     * example:
     * 2018-02-06
     */
    last_repayment_date?: string;
    /**
     * example:
     * 2018-02-06
     */
    next_repayment_date?: string;
    /**
     * example:
     * 1.5
     */
    up_partner_repayment_percentage?: number;
    /**
     * example:
     * false
     */
    allow_express: boolean;
    /**
     * example:
     * Number 123
     */
    account_number?: string;
    affiliate_accounts?: AffiliateAccount[];
    products?: Product[];
}
export interface AffiliateStaff {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    id: string;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    affiliate_id: string;
    /**
     * example:
     * novak@email.cz
     */
    email?: string;
    /**
     * example:
     * Jan
     */
    first_name?: string;
    /**
     * example:
     * Novak
     */
    last_name?: string;
    /**
     * example:
     * +420 777 777 777
     */
    phone?: string;
    /**
     * example:
     * false
     */
    all_affiliate_merchant: boolean;
}
export interface AffiliateStaffMerchant {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    id: string;
    affiliate_staff: AffiliateStaff;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    merchant_id: string;
    affiliate_staff_role: AffiliateStaffRole;
}
export interface AffiliateStaffMerchantsResponse {
    pagination: Pagination;
    data: AffiliateStaffMerchant[];
}
export interface AffiliateStaffRole {
    /**
     * example:
     * 123
     */
    id: number;
    /**
     * example:
     * Name 123
     */
    name: string;
}
export interface AffiliateStaffRolesResponse {
    pagination: Pagination;
    data: AffiliateStaffRole[];
}
export interface AffiliateStaffsResponse {
    pagination: Pagination;
    data: AffiliateStaff[];
}
export interface AffiliatesResponse {
    pagination: Pagination;
    data: Affiliate[];
}
export interface Bound {
    left_buttom?: Gps;
    right_top?: Gps;
}
export interface Branch {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    id: string;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    client_id: string;
    /**
     * example:
     * Code 123
     */
    code?: string;
    /**
     * example:
     * Name 123
     */
    name?: string;
    /**
     * example:
     * XXX 123
     */
    remark?: string;
}
export interface BranchesResponse {
    pagination: Pagination;
    data: Branch[];
}
export interface BulkBody {
    ids: string[];
    /**
     * 1-delete
     * example:
     * 1
     */
    operation: number;
}
export interface Card {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    id: string;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    holder_account_id: string;
    /**
     * example:
     * 1234
     */
    pan4?: number;
    /**
     * example:
     * 2018-02-06 12:00
     */
    status_last_changed?: string;
    /**
     * example:
     * false
     */
    gdf?: boolean;
    /**
     * example:
     * 2018-02-06 12:00
     */
    valid_to?: string;
    /**
     * example:
     * 123
     */
    status_id: number;
    /**
     * example:
     * Aktívna
     */
    status_text?: string;
    /**
     * example:
     * true
     */
    auto_renew?: boolean;
    /**
     * example:
     * false
     */
    readonly can_activate?: boolean;
    /**
     * example:
     * false
     */
    readonly can_deactivate?: boolean;
    /**
     * example:
     * false
     */
    readonly can_block?: boolean;
    /**
     * example:
     * true
     */
    readonly can_auto_renew?: boolean;
    /**
     * example:
     * ?
     */
    readonly pan?: string;
    /**
     * Read only object.
     */
    readonly employee?: {
        /**
         * example:
         * 123e4567-e89b-12d3-a456-426655440000
         */
        id: string;
        address: Address;
        /**
         * example:
         * 123e4567-e89b-12d3-a456-426655440000
         */
        client_id?: string;
        delivery_address: DeliveryAddress;
        department: Department;
        /**
         * example:
         * Title 123
         */
        title?: string;
        /**
         * example:
         * Jan
         */
        first_name?: string;
        /**
         * example:
         * Novak
         */
        last_name?: string;
        /**
         * example:
         * novak@email.cz
         */
        email?: string;
        /**
         * example:
         * +420 777 777 777
         */
        phone?: string;
        /**
         * example:
         * 2018-02-06 12:00
         */
        last_login?: string;
        /**
         * example:
         * 123456
         */
        number: string;
        /**
         * example:
         * 123e4567-e89b-12d3-a456-426655440000
         */
        holder_id?: string;
        /**
         * example:
         * false
         */
        active: boolean;
    };
}
export interface CardsBulkBody {
    ids: string[];
    /**
     * 1 - Activate, 2 - Deactivate
     * example:
     * 1
     */
    operation: number;
}
export interface CardsResponse {
    pagination: Pagination;
    data: Card[];
}
export interface ChangePassword {
    old_password?: string;
    new_password?: string;
}
export interface Client {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    id: string;
    address?: Address;
    /**
     * example:
     * Name 123
     */
    name?: string;
    /**
     * example:
     * RegIdent 123
     */
    registration_identification?: string;
    /**
     * example:
     * VAT 123
     */
    vat_identification?: string;
    /**
     * example:
     * 1234567890
     */
    tax_identification?: string;
    /**
     * example:
     * novak@email.cz
     */
    email?: string;
    /**
     * example:
     * 123
     */
    image_logo_paper_id?: number;
    /**
     * example:
     * 123
     */
    image_logo_card_id?: number;
    /**
     * example:
     * 123
     */
    image_logo_cover_latter_id?: number;
    /**
     * example:
     * Text 123
     */
    text_cover_letter?: string;
    /**
     * example:
     * Text 123
     */
    text_card?: string;
    /**
     * example:
     * false
     */
    allow_employee_change_login?: boolean;
    /**
     * Emails manipulation (read only)
     * example:
     * false
     */
    readonly emails_manipulation?: boolean;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    image_logo_color_id?: string;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    image_logo_grayscale_id?: string;
    /**
     * example:
     * false
     */
    cover_sheet_use_logo?: boolean;
    /**
     * example:
     * Text 123
     */
    cover_sheet_text?: string;
}
export interface ClientDetail {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    id: string;
    address?: Address;
    /**
     * example:
     * Name 123
     */
    name?: string;
    /**
     * example:
     * RegIdent 123
     */
    registration_identification?: string;
    /**
     * example:
     * VAT 123
     */
    vat_identification?: string;
    /**
     * example:
     * 1234567890
     */
    tax_identification?: string;
    /**
     * example:
     * novak@email.cz
     */
    email?: string;
    /**
     * example:
     * 123
     */
    image_logo_paper_id?: number;
    /**
     * example:
     * 123
     */
    image_logo_card_id?: number;
    /**
     * example:
     * 123
     */
    image_logo_cover_latter_id?: number;
    /**
     * example:
     * Text 123
     */
    text_cover_letter?: string;
    /**
     * example:
     * Text 123
     */
    text_card?: string;
    /**
     * example:
     * false
     */
    allow_employee_change_login?: boolean;
    /**
     * Emails manipulation (read only)
     * example:
     * false
     */
    readonly emails_manipulation?: boolean;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    image_logo_color_id?: string;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    image_logo_grayscale_id?: string;
    /**
     * example:
     * false
     */
    cover_sheet_use_logo?: boolean;
    /**
     * example:
     * Text 123
     */
    cover_sheet_text?: string;
    contact_persons?: ContactPerson[];
}
export interface ClientProduct {
    /**
     * example:
     * line 1
     */
    text_voucher_line1?: string;
    /**
     * example:
     * line 2
     */
    text_voucher_line2?: string;
    /**
     * example:
     * cover 1
     */
    text_cover_letter_line1?: string;
    /**
     * example:
     * cover 2
     */
    text_cover_letter_line2?: string;
    product?: Product;
}
export interface ClientProductImage {
    /**
     * example:
     * line 1
     */
    text_voucher_line1?: string;
    /**
     * example:
     * line 2
     */
    text_voucher_line2?: string;
    /**
     * example:
     * cover 1
     */
    text_cover_letter_line1?: string;
    /**
     * example:
     * cover 2
     */
    text_cover_letter_line2?: string;
    product?: Product;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    image_id: string;
}
export interface ClientProductsResponse {
    pagination: Pagination;
    data: ClientProduct[];
}
export interface ClientsCheck {
    /**
     * example:
     * 2018-02-06
     */
    promo_valid_date?: string;
    /**
     * example:
     * 2018-02-06
     */
    promo_date?: string;
    /**
     * example:
     * false
     */
    existing_client?: boolean;
    /**
     * example:
     * false
     */
    has_promo?: boolean;
    /**
     * example:
     * novak@email.cz
     */
    promo_email?: string;
    product_ids?: any;
}
export interface ClientsRegistration {
    /**
     * example:
     * Jan Novák
     */
    name?: string;
    address?: Address;
    billing_address?: Address;
    /**
     * example:
     * false
     */
    billing_address_is_the_same?: boolean;
    /**
     * example:
     * 123456789
     */
    registration_identification?: string;
    /**
     * example:
     * 123456789
     */
    vat_identification?: string;
    /**
     * example:
     * false
     */
    no_vat_identification?: boolean;
    /**
     * example:
     * novak@email.cz
     */
    email?: string;
    /**
     * example:
     * x12As@83
     */
    password?: string;
    promo_code?: string;
}
export interface ClientsResponse {
    pagination: Pagination;
    data: Client[];
}
export interface ConfigurableVoucherItem {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    delivery_address_id?: string;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    department_id?: string;
    /**
     * example:
     * 1
     */
    packaging_count?: number;
    values: VoucherValueItem[];
    /**
     * example:
     * 123e4567
     */
    uid?: string;
    employee_id?: string;
}
export interface Contact {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    id: string;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    merchant_id: string;
    /**
     * example:
     * 123
     */
    function_id: number;
    /**
     * example:
     * novak@email.cz
     */
    email?: string;
    /**
     * example:
     * +420 777 777 777
     */
    phone?: string;
}
export interface ContactPerson {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    id: string;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    client_id: string;
    /**
     * example:
     * Jan
     */
    first_name?: string;
    /**
     * example:
     * Novak
     */
    last_name?: string;
    /**
     * example:
     * novak@email.cz
     */
    email?: string;
    /**
     * example:
     * +420 777 777 777
     */
    phone?: string;
}
export interface CountriesResponse {
    pagination: Pagination;
    data: Country[];
}
export interface Country {
    /**
     * example:
     * 123
     */
    id: number;
    /**
     * example:
     * CZ
     */
    code: string;
    /**
     * example:
     * Czech republic
     */
    name: string;
}
export interface Credit {
    /**
     * example:
     * 2018-02-06 12:00 alebo text
     */
    expiry_date?: string;
    /**
     * example:
     * 1.5
     */
    amount?: number;
}
export interface CreditMemo {
    /**
     * example:
     * 1.5
     */
    value: number;
}
export interface CurrenciesResponse {
    pagination: Pagination;
    data: Currency[];
}
export interface Currency {
    /**
     * example:
     * 123
     */
    id: number;
    /**
     * example:
     * CZK
     */
    code: string;
    /**
     * example:
     * Kč
     */
    name: string;
}
export interface Dashboard {
    /**
     * example:
     * xyz
     */
    name?: string;
    sales_manager?: SalesManager;
    /**
     * example:
     * 12
     */
    number_of_employees?: number;
    /**
     * example:
     * 3
     */
    number_of_delivery_addresses?: number;
}
export interface DeliveryAddress {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    id: string;
    address: Address;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    branch_id: string;
    contact_person: ContactPerson;
    /**
     * example:
     * Name 123
     */
    code?: string;
    /**
     * example:
     * Name 123
     */
    name?: string;
    /**
     * example:
     * Name 123
     */
    remark?: string;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    client_id?: string;
    responsible_person_for_order?: ContactPerson;
    /**
     * example:
     * 123
     */
    readonly number_of_employees?: number;
}
export interface DeliveryAddressEmployee {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    id: string;
    address: Address;
    /**
     * example:
     * Title 123
     */
    title?: string;
    /**
     * example:
     * Jan
     */
    first_name?: string;
    /**
     * example:
     * Novak
     */
    last_name?: string;
    /**
     * example:
     * novak@email.cz
     */
    email?: string;
    /**
     * example:
     * +420 777 777 777
     */
    phone?: string;
    /**
     * example:
     * 123456
     */
    number: string;
    /**
     * example:
     * false
     */
    is_administrator: boolean;
}
export interface DeliveryAddressEmployeesResponse {
    pagination: Pagination;
    data: DeliveryAddressEmployee[];
}
export interface DeliveryAddressesResponse {
    pagination: Pagination;
    data: DeliveryAddress[];
}
export interface DeliveryType {
    /**
     * example:
     * 123
     */
    id: number;
    /**
     * example:
     * Name 123
     */
    name: string;
    delivery_time?: string;
    delivery_fee?: string;
    fee_amount?: number;
    sub_types?: DeliveryType[];
}
export interface DeliveryTypesResponse {
    pagination: Pagination;
    data: DeliveryType[];
}
export interface Department {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    id: string;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    client_id: string;
    /**
     * example:
     * Name 123
     */
    name: string;
    /**
     * example:
     * Code 123
     */
    code: string;
    /**
     * example:
     * 123
     */
    readonly number_of_employees?: number;
}
export interface DepartmentsResponse {
    pagination: Pagination;
    data: Department[];
}
export interface Document {
    id?: string;
    number?: string;
    name?: string;
    type?: string;
    category_type_id?: number;
    contract_type_id?: string;
    items?: DocumentItem[];
    /**
     * example:
     * 2018-02-06 12:00
     */
    date?: string;
    product_code?: string;
}
export interface DocumentCategoryType {
    id: number;
    /**
     * example:
     * Name 123
     */
    name: string;
}
export interface DocumentCategoryTypesResponse {
    pagination: Pagination;
    data: DocumentCategoryType[];
}
export interface DocumentContractType {
    id: string;
    /**
     * example:
     * Name 123
     */
    name: string;
}
export interface DocumentContractTypesResponse {
    pagination: Pagination;
    data: DocumentContractType[];
}
export interface DocumentItem {
    link?: string;
    name?: string;
    type?: string;
}
export interface DocumentType {
    id: string;
    /**
     * example:
     * Name 123
     */
    name: string;
    scope_id?: number;
    category_type_id?: number;
}
export interface DocumentTypesResponse {
    pagination: Pagination;
    data: DocumentType[];
}
export interface Employee {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    id: string;
    address: Address;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    client_id?: string;
    delivery_address: DeliveryAddress;
    department: Department;
    /**
     * example:
     * Title 123
     */
    title?: string;
    /**
     * example:
     * Jan
     */
    first_name?: string;
    /**
     * example:
     * Novak
     */
    last_name?: string;
    /**
     * example:
     * novak@email.cz
     */
    email?: string;
    /**
     * example:
     * +420 777 777 777
     */
    phone?: string;
    /**
     * example:
     * 2018-02-06 12:00
     */
    last_login?: string;
    /**
     * example:
     * 123456
     */
    number: string;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    holder_id?: string;
    /**
     * example:
     * false
     */
    active: boolean;
}
export interface EmployeeDetail {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    id: string;
    address: Address;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    client_id?: string;
    delivery_address: DeliveryAddress;
    department: Department;
    /**
     * example:
     * Title 123
     */
    title?: string;
    /**
     * example:
     * Jan
     */
    first_name?: string;
    /**
     * example:
     * Novak
     */
    last_name?: string;
    /**
     * example:
     * novak@email.cz
     */
    email?: string;
    /**
     * example:
     * +420 777 777 777
     */
    phone?: string;
    /**
     * example:
     * 2018-02-06 12:00
     */
    last_login?: string;
    /**
     * example:
     * 123456
     */
    number: string;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    holder_id?: string;
    /**
     * example:
     * false
     */
    active: boolean;
    holder_accounts?: HolderAccount[];
}
export interface EmployeeFind {
    /**
     * example:
     * Jan
     */
    first_name: string;
    /**
     * example:
     * Novak
     */
    last_name: string;
    /**
     * example:
     * 123456
     */
    number: string;
    /**
     * example:
     * 123456
     */
    card_number: string;
    /**
     * example:
     * 123456
     */
    account_number: string;
}
export interface EmployeeNotification {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    id: string;
    /**
     * example:
     * 123
     */
    type_id?: number;
    /**
     * example:
     * false
     */
    email?: boolean;
    /**
     * example:
     * false
     */
    sms?: boolean;
}
export interface EmployeeNotificationsResponse {
    pagination: Pagination;
    data: EmployeeNotification[];
}
export interface EmployeesBulk {
    ids: string[];
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    object_id?: string;
    /**
     * 1-delete, 2-set delivery address, 3-set department, 4-activation, 5-deactivaction
     * example:
     * 1
     */
    operation: number;
}
export interface EmployeesResponse {
    pagination: Pagination;
    data: Employee[];
}
export interface File {
    /**
     * example:
     * test.pdf
     */
    file_name: string;
    /**
     * BASE64
     * example:
     * 116cfgnbfg616fgnsXb56
     */
    byte_data: string;
    /**
     * example:
     * 1
     */
    file_id?: number;
}
export interface ForgotPasswordBody {
    /**
     * example:
     * novak@email.cz
     */
    email: string;
}
export interface Function {
    /**
     * example:
     * 123
     */
    id: number;
    /**
     * example:
     * Name 123
     */
    name: string;
}
export interface FunctionsResponse {
    pagination: Pagination;
    data: Function[];
}
export interface Gps {
    /**
     * example:
     * 1.5
     */
    longitude?: number;
    /**
     * example:
     * 1.5
     */
    latitude?: number;
}
export interface History {
    /**
     * example:
     * 123
     */
    id: number;
    /**
     * example:
     * 2018-02-06 12:00
     */
    date: string;
    /**
     * example:
     * test ...
     */
    note: string;
}
export interface HistoryResponse {
    pagination: Pagination;
    data: History[];
}
export interface HolderAccount {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    id: string;
    /**
     * example:
     * Acc123
     */
    name: string;
    /**
     * example:
     * 1.5
     */
    amount?: number;
    /**
     * example:
     * 123
     */
    product_id: number;
    /**
     * example:
     * 2018-02-06 12:00
     */
    last_recharge_date?: string;
    cards?: Card[];
    currency?: Currency;
    /**
     * example:
     * 2018-02-06
     */
    validity_to?: string;
}
export interface ImportRow {
    /**
     * example:
     * 123
     */
    id: number;
    employee: EmployeeDetail;
    delivery_address?: DeliveryAddress;
    count: number;
    value: number;
}
export interface ImportRowsResponse {
    pagination: Pagination;
    data: ImportRow[];
}
export interface Language {
    /**
     * example:
     * 123
     */
    id: number;
    /**
     * example:
     * Name 123
     */
    name: string;
    /**
     * example:
     * Code 123
     */
    code: string;
    /**
     * example:
     * Name 123
     */
    short_name: string;
}
export interface LanguagesResponse {
    pagination: Pagination;
    data: Language[];
}
export interface LastSendAmountHolder {
    recipient_name?: string;
    /**
     * example:
     * 2301
     */
    id?: number;
}
export interface LastSendAmountHoldersResponse {
    pagination: Pagination;
    data: LastSendAmountHolder[];
}
export interface LogoutRequest {
    client_id?: string;
    client_secret?: string;
    refresh_token?: string;
}
export interface Merchant {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    id: string;
    address?: Address;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    merchant_request_id?: string;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    affiliate_id?: string;
    /**
     * example:
     * Name 123
     */
    name?: string;
    /**
     * example:
     * novak@email.cz
     */
    email?: string;
    /**
     * example:
     * +420 777 777 777
     */
    phone?: string;
    /**
     * example:
     * 1.5
     */
    latitude?: number;
    /**
     * example:
     * 1.5
     */
    longitude?: number;
    /**
     * example:
     * 1.5
     */
    readonly distance?: number;
    types?: MerchantType[];
    products?: Product[];
}
export interface MerchantDetail {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    id: string;
    address?: Address;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    merchant_request_id?: string;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    affiliate_id?: string;
    /**
     * example:
     * Name 123
     */
    name?: string;
    /**
     * example:
     * novak@email.cz
     */
    email?: string;
    /**
     * example:
     * +420 777 777 777
     */
    phone?: string;
    /**
     * example:
     * 1.5
     */
    latitude?: number;
    /**
     * example:
     * 1.5
     */
    longitude?: number;
    /**
     * Distance (read only)
     * example:
     * 1.5
     */
    readonly distance?: number;
    types?: MerchantType[];
    products?: Product[];
    payment_channel_types?: PaymentChannelType[];
    contacts?: Contact[];
    websites?: Website[];
    opening_hours?: OpeningHour[];
}
export interface MerchantRequest {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    id: string;
    merchant_request_state: MerchantRequestState;
    /**
     * example:
     * 2018-02-06 12:00
     */
    date_time?: string;
    /**
     * example:
     * Name 123
     */
    name?: string;
    /**
     * example:
     * novak@email.cz
     */
    email?: string;
    /**
     * example:
     * +420 777 777 777
     */
    phone?: string;
}
export interface MerchantRequestDetail {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    id: string;
    merchant_request_state: MerchantRequestState;
    /**
     * example:
     * 2018-02-06 12:00
     */
    date_time?: string;
    /**
     * example:
     * Name 123
     */
    name?: string;
    /**
     * example:
     * novak@email.cz
     */
    email?: string;
    /**
     * example:
     * +420 777 777 777
     */
    phone?: string;
    types?: MerchantType[];
    products?: Product[];
    addresses?: Address[];
}
export interface MerchantRequestState {
    /**
     * example:
     * 123
     */
    id: number;
    /**
     * example:
     * Name 123
     */
    name: string;
}
export interface MerchantRequestStatesResponse {
    pagination: Pagination;
    data: MerchantRequestState[];
}
export interface MerchantRequestsResponse {
    pagination: Pagination;
    data: MerchantRequest[];
}
export interface MerchantSimple {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    id: string;
    /**
     * example:
     * Name 123
     */
    name?: string;
    address?: Address;
}
export interface MerchantType {
    /**
     * example:
     * 123
     */
    id: number;
    /**
     * example:
     * Name 123
     */
    name: string;
}
export interface MerchantTypesResponse {
    pagination: Pagination;
    data: MerchantType[];
}
export interface MerchantsResponse {
    pagination: Pagination;
    data: Merchant[];
    /**
     * example:
     * false
     */
    gdf?: boolean;
}
export interface MerchantsSearch {
    /**
     * example:
     * abcd
     */
    text?: string;
    products_ids?: number[];
    /**
     * example:
     * false
     */
    mobile_payment?: boolean;
    types_ids?: number[];
    /**
     * example:
     * 1.5
     */
    gps_latitude?: number;
    /**
     * example:
     * 1.5
     */
    gps_longitude?: number;
    /**
     * example:
     * 1
     */
    page?: number;
    /**
     * example:
     * 10
     */
    per_page?: number;
    gps_order?: Gps;
    gps_distance?: Gps;
    gps_filter?: Bound;
}
export interface MerchantsSearchClustering {
    /**
     * example:
     * abcd
     */
    text?: string;
    products_ids?: number[];
    /**
     * example:
     * false
     */
    mobile_payment?: boolean;
    types_ids?: number[];
    /**
     * example:
     * 1.5
     */
    west_longitude?: number;
    /**
     * example:
     * 1.5
     */
    south_latitude?: number;
    /**
     * example:
     * 1.5
     */
    east_longitude?: number;
    /**
     * example:
     * 1.5
     */
    north_latitude?: number;
    /**
     * example:
     * false
     */
    use_clustering: boolean;
}
export interface MerchantsSearchClusteringResult {
    /**
     * 1 - cluster, 2 - place
     * example:
     * 1
     */
    type?: number;
    gps?: Gps;
    /**
     * example:
     * 1
     */
    count?: number;
    place?: MerchantSimple;
    bound?: Bound;
}
export interface Message {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    id: string;
    title?: Text;
    perex?: Text;
    text?: Text;
    /**
     * example:
     * 2018-02-06 12:00
     */
    published_at?: string;
    /**
     * example:
     * 12
     */
    days_after_products_purchase?: number;
    products?: number[];
    targets?: string[];
    /**
     * example:
     * false
     */
    is_acknowledged: boolean;
}
export interface MessageState {
    /**
     * example:
     * 123
     */
    id: number;
    /**
     * example:
     * Name 123
     */
    name: string;
}
export interface MessageStatesResponse {
    pagination: Pagination;
    data: MessageState[];
}
export interface MessageType {
    /**
     * example:
     * 123
     */
    id: number;
    /**
     * example:
     * Name 123
     */
    name: string;
}
export interface MessageTypesResponse {
    pagination: Pagination;
    data: MessageType[];
}
export interface MessagesResponse {
    pagination: Pagination;
    data: Message[];
}
export interface NewCardItem {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    employee_id: string;
    /**
     * example:
     * Peter Novak
     */
    name_on_card?: string;
    values: VoucherValueItem[];
    /**
     * example:
     * 123e4567
     */
    uid?: string;
}
export interface NewClientRegistration {
    /**
     * example:
     * test
     */
    name: string;
    /**
     * example:
     * test
     */
    registration_identification?: string;
    /**
     * example:
     * test
     */
    vat_identification?: string;
    /**
     * example:
     * test
     */
    tax_identification?: string;
    /**
     * example:
     * novak@email.cz
     */
    email?: string;
    /**
     * example:
     * 123
     */
    image_logo_paper_id?: number;
    /**
     * example:
     * 123
     */
    image_logo_card_id?: number;
    /**
     * example:
     * 123
     */
    image_logo_cover_latter_id?: number;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    image_logo_color_id?: string;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    image_logo_grayscale_id?: string;
    /**
     * example:
     * test
     */
    text_cover_letter?: string;
    /**
     * example:
     * test
     */
    text_card?: string;
    /**
     * example:
     * Jan
     */
    contact_person_first_name?: string;
    /**
     * example:
     * Novák
     */
    contact_person_last_name?: string;
    /**
     * example:
     * novak@email.cz
     */
    contact_person_email?: string;
    /**
     * example:
     * +420 777 777 777
     */
    contact_person_phone?: string;
    /**
     * example:
     * Jan Novák
     */
    address_name?: string;
    /**
     * example:
     * 25601
     */
    address_postcode?: string;
    /**
     * example:
     * Vančurova 914
     */
    address_street?: string;
    /**
     * example:
     * Benešov
     */
    address_city?: string;
    /**
     * example:
     * 1
     */
    address_country_id?: number;
    /**
     * example:
     * novak@email.cz
     */
    login_email: string;
    /**
     * example:
     * false
     */
    cover_sheet_use_logo: boolean;
    /**
     * example:
     * test
     */
    cover_sheet_text?: string;
    /**
     * example:
     * Jan Novák
     */
    delivery_address_name?: string;
    /**
     * example:
     * 25601
     */
    delivery_address_postcode?: string;
    /**
     * example:
     * Vančurova 914
     */
    delivery_address_street?: string;
    /**
     * example:
     * Benešov
     */
    delivery_address_city?: string;
    /**
     * example:
     * 1
     */
    delivery_address_country_id?: number;
    /**
     * example:
     * test
     */
    address_note?: string;
    /**
     * example:
     * false
     */
    delivery_address_same_as_invoice: boolean;
}
export interface Notice {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    id: string;
    title?: Text;
    perex?: Text;
    text?: Text;
    /**
     * example:
     * 2018-02-06 12:00
     */
    published_at?: string;
    /**
     * example:
     * 12
     */
    days_after_products_purchase?: number;
    products?: number[];
    targets?: string[];
    /**
     * example:
     * false
     */
    is_acknowledged: boolean;
    app_types?: string[];
    languages?: string[];
    zips?: string[];
}
export interface NoticesResponse {
    pagination: Pagination;
    data: Notice[];
}
export interface Notification {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    id: string;
    /**
     * example:
     * 1
     */
    type_id: number;
    /**
     * example:
     * false
     */
    email: boolean;
    /**
     * example:
     * false
     */
    sms: boolean;
}
export interface NotificationGroup {
    /**
     * example:
     * 123
     */
    id: number;
    /**
     * example:
     * Group 123
     */
    name: string;
}
export interface NotificationType {
    /**
     * example:
     * 123
     */
    id: number;
    /**
     * example:
     * Name 123
     */
    name: string;
    /**
     * example:
     * 123
     */
    scope_id: number;
    /**
     * example:
     * false
     */
    email: boolean;
    /**
     * example:
     * false
     */
    sms: boolean;
    notification_group: NotificationGroup;
}
export interface NotificationTypesResponse {
    pagination: Pagination;
    data: NotificationType[];
}
export interface NotificationsResponse {
    pagination: Pagination;
    data: Notification[];
}
export interface OpeningHour {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    id: string;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    merchant_id: string;
    /**
     * example:
     * 1
     */
    day: number;
    /**
     * example:
     * 8
     */
    opened_from_hour: number;
    /**
     * example:
     * 0
     */
    opened_from_minute: number;
    /**
     * example:
     * 15
     */
    opened_to_hour: number;
    /**
     * example:
     * 30
     */
    opened_to_minute: number;
}
export interface Order {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    id: string;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    client_id: string;
    /**
     * example:
     * 123
     */
    denomination?: number;
    /**
     * example:
     * Eur
     */
    currency?: string;
    new_client_registration?: NewClientRegistration;
    /**
     * example:
     * 123
     */
    payment_type: number;
    /**
     * example:
     * 123
     */
    internal_number?: string;
    promo_code?: string;
    /**
     * example:
     * 123
     */
    order_periodicity?: number;
    /**
     * example:
     * 10
     */
    delivery_hour?: number;
    /**
     * example:
     * 2010-01-01
     */
    delivery_date?: string;
    initialized_anonymously?: boolean;
    card_products: OrderProductCard[];
    voucher_products: OrderProductVoucher[];
}
export interface OrderAddProductBody {
    /**
     * example:
     * 1
     */
    product_id: number;
}
export interface OrderBinding {
    /**
     * example:
     * 123
     */
    id: number;
    /**
     * example:
     * Name 123
     */
    name: string;
}
export interface OrderBindingsResponse {
    pagination: Pagination;
    data: OrderBinding[];
}
export interface OrderConfirmBody {
    /**
     * example:
     * www.xyz.com
     */
    callback_url: string;
}
export interface OrderDeliveryAddress {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    id: string;
    address: Address;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    branch_id: string;
    contact_person: ContactPerson;
    /**
     * example:
     * Name 123
     */
    code?: string;
    /**
     * example:
     * Name 123
     */
    name?: string;
    /**
     * example:
     * Name 123
     */
    remark?: string;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    client_id?: string;
    responsible_person_for_order?: ContactPerson;
    /**
     * example:
     * 123
     */
    readonly number_of_employees?: number;
    departments: Department[];
    employees: Employee[];
    /**
     * example:
     * 12
     */
    readonly count_of_employees?: number;
    /**
     * example:
     * 12
     */
    readonly count_of_departments?: number;
}
export interface OrderDeliveryAddressesResponse {
    pagination: Pagination;
    data: OrderDeliveryAddress[];
}
export interface OrderList {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    id?: string;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    order_product_id?: string;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    client_id?: string;
    /**
     * example:
     * 123
     */
    denomination?: number;
    /**
     * example:
     * Eur
     */
    currency?: string;
    /**
     * example:
     * 2010-01-01
     */
    date?: string;
    address?: string;
    state?: OrderState;
    amount?: number;
    product?: string;
}
export interface OrderProduct {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    id: string;
    /**
     * example:
     * 123
     */
    product_id: number;
    /**
     * 1 - voucher, 2 - card
     * example:
     * 1
     */
    product_type: number;
    delivery_type_id: number;
    /**
     * example:
     * false
     */
    print_logo?: boolean;
    /**
     * example:
     * false
     */
    print_employee_name?: boolean;
    /**
     * example:
     * false
     */
    print_employee_number?: boolean;
    /**
     * example:
     * false
     */
    print_text?: boolean;
    /**
     * example:
     * 1
     */
    order_binding?: number;
    /**
     * example:
     * 1000
     */
    max_voucher_value?: number;
    /**
     * example:
     * 10
     */
    min_voucher_value?: number;
    /**
     * example:
     * 100
     */
    default_voucher_value?: number;
}
export interface OrderProductCard {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    id: string;
    /**
     * example:
     * 123
     */
    product_id: number;
    /**
     * 1 - voucher, 2 - card
     * example:
     * 1
     */
    product_type: number;
    delivery_type_id: number;
    /**
     * example:
     * false
     */
    print_logo?: boolean;
    /**
     * example:
     * false
     */
    print_employee_name?: boolean;
    /**
     * example:
     * false
     */
    print_employee_number?: boolean;
    /**
     * example:
     * false
     */
    print_text?: boolean;
    /**
     * example:
     * 1
     */
    order_binding?: number;
    /**
     * example:
     * 1000
     */
    max_voucher_value?: number;
    /**
     * example:
     * 10
     */
    min_voucher_value?: number;
    /**
     * example:
     * 100
     */
    default_voucher_value?: number;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    preloaded_from_order_id: string;
    /**
     * example:
     * false
     */
    first_order: boolean;
    /**
     * example:
     * 2010-01-01
     */
    credit_activation_date?: string;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    import_id?: string;
    /**
     * 1 - to_company_addresses, 2 - to_employee_addresses
     * example:
     * 1
     */
    import_type?: number;
    /**
     * example:
     * false
     */
    order_aditional_cards: boolean;
    /**
     * example:
     * false
     */
    with_personalization: boolean;
    charge_credit: OrderProductCardItemChargeCredit[];
    order_new_cards: OrderProductCardItemOrderCardsNewCards;
}
export interface OrderProductCardItemChargeCredit {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    employee_id: string;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    order_product_id: string;
    values: VoucherValueItem[];
}
export interface OrderProductCardItemOrderCardsNewCards {
    /**
     * example:
     * false
     */
    order_cards_with_credit: boolean;
    new_cards: NewCardItem[];
    /**
     * 1 - one_specific_delivery_address, 2 - employee_delivery_addresses, 3 - one_specific_delivery_address_after_sign_on, 4 - employee_personal_addresses
     * example:
     * 1
     */
    delivery_address_type?: number;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    delivery_address_id?: string;
    /**
     * example:
     * test
     */
    delivery_note?: string;
}
export interface OrderProductVoucher {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    id: string;
    /**
     * example:
     * 123
     */
    product_id: number;
    /**
     * 1 - voucher, 2 - card
     * example:
     * 1
     */
    product_type: number;
    delivery_type_id: number;
    /**
     * example:
     * false
     */
    print_logo?: boolean;
    /**
     * example:
     * false
     */
    print_employee_name?: boolean;
    /**
     * example:
     * false
     */
    print_employee_number?: boolean;
    /**
     * example:
     * false
     */
    print_text?: boolean;
    /**
     * example:
     * 1
     */
    order_binding?: number;
    /**
     * example:
     * 1000
     */
    max_voucher_value?: number;
    /**
     * example:
     * 10
     */
    min_voucher_value?: number;
    /**
     * example:
     * 100
     */
    default_voucher_value?: number;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    preloaded_from_order_id?: string;
    /**
     * 1 - prepacked, 2 - individual, 3 - configurable
     * example:
     * 1
     */
    packaging?: number;
    /**
     * 1 - one_specific_delivery_address, 2 - employee_delivery_addresses, 3 - one_specific_delivery_address_after_sign_on, 4 - employee_personal_addresses
     * example:
     * 1
     */
    delivery_address_type?: number;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    delivery_address_id?: string;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    employee_id?: string;
    /**
     * example:
     * test
     */
    name?: string;
    /**
     * example:
     * 1
     */
    count?: number;
    prepacked?: OrderProductVoucherItemPrepacked;
    individual?: OrderProductVoucherItemIndividual;
    configurable?: OrderProductVoucherItemConfigurable;
    /**
     * example:
     * test
     */
    delivery_note?: string;
}
export interface OrderProductVoucherItemConfigurable {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    import_id?: string;
    /**
     * example:
     * false
     */
    personalized?: boolean;
    /**
     * 1 - name, 2 - number, 3 - name_and_number
     * example:
     * 1
     */
    personalization_type?: number;
    /**
     * 1 - name, 2 - surname, 3 - number
     * example:
     * 1
     */
    personalization_sorting?: number;
    vouchers: ConfigurableVoucherItem[];
    additional_prepacked?: OrderProductVoucherItemConfigurableAdditional;
}
export interface OrderProductVoucherItemConfigurableAdditional {
    vouchers: VoucherItem[];
}
export interface OrderProductVoucherItemIndividual {
    vouchers: VoucherItem[];
}
export interface OrderProductVoucherItemPrepacked {
    vouchers: VoucherItem[];
}
export interface OrderSidebar {
    /**
     * example:
     * 123
     */
    denomination?: number;
    /**
     * example:
     * Eur
     */
    currency?: string;
    above?: SidebarItem[];
    below?: SidebarItem[];
}
/**
 * 0 = Edit, 2 = Confirmed, 3 = Deleted
 */
export interface OrderState {
    /**
     * example:
     * 123
     */
    id: number;
    /**
     * example:
     * Name 123
     */
    name: string;
}
export interface OrderStatesResponse {
    pagination: Pagination;
    data: OrderState[];
}
export interface OrderSummary {
    /**
     * example:
     * 123
     */
    denomination?: number;
    /**
     * example:
     * Eur
     */
    currency?: string;
    amount?: number;
}
export interface OrdersConfirmResult {
    id?: {};
    messages?: ResultMessage[];
    inner_exception?: string;
    /**
     * example:
     * www.xyz.com
     */
    redirect_url: string;
}
export interface OrdersResponse {
    pagination: Pagination;
    data: OrderList[];
}
export interface Pagination {
    /**
     * example:
     * 10
     */
    object_count?: number;
    /**
     * example:
     * 1
     */
    page?: number;
    /**
     * example:
     * 10
     */
    per_page?: number;
}
export interface Payment {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    merchat_id: string;
    /**
     * example:
     * 1.5
     */
    amount: number;
    /**
     * example:
     * 1.5
     */
    tip: number;
    /**
     * example:
     * 123
     */
    cvv: string;
}
export interface PaymentChannelType {
    /**
     * example:
     * 123
     */
    id: number;
    /**
     * example:
     * Name 123
     */
    name: string;
}
export interface PaymentChannelTypesResponse {
    pagination: Pagination;
    data: PaymentChannelType[];
}
export interface PaymentType {
    /**
     * example:
     * 123
     */
    id: number;
    /**
     * example:
     * Name 123
     */
    name: string;
    tooltip?: string;
    parent_id?: number;
    sub_types?: PaymentType[];
}
export interface PaymentTypesResponse {
    pagination: Pagination;
    data: PaymentType[];
}
export interface Product {
    /**
     * example:
     * 123
     */
    id: number;
    /**
     * example:
     * Code 123
     */
    code?: string;
    /**
     * example:
     * Name 123
     */
    name: string;
    /**
     * example:
     * 1.5
     */
    nominal_value_min?: number;
    /**
     * example:
     * 1.5
     */
    nominal_value_max?: number;
    /**
     * example:
     * 1.5
     */
    nominal_value_default?: number;
    /**
     * example:
     * 12
     */
    max_bind_count?: number;
    /**
     * example:
     * Text 123
     */
    description1?: string;
    /**
     * example:
     * Text 123
     */
    description2?: string;
    /**
     * example:
     * Text 123
     */
    description3?: string;
    /**
     * example:
     * Text 123
     */
    bound_value?: string;
}
export interface ProductsResponse {
    pagination: Pagination;
    data: Product[];
}
export interface RepaymentFrequenciesResponse {
    pagination: Pagination;
    data: RepaymentFrequency[];
}
export interface RepaymentFrequency {
    /**
     * example:
     * 123
     */
    id: number;
    /**
     * example:
     * Name 123
     */
    name: string;
    /**
     * example:
     * 1.5
     */
    fee_percentage?: number;
}
export interface RequestType {
    /**
     * example:
     * 123
     */
    id: number;
    /**
     * example:
     * Name 123
     */
    name: string;
}
export interface RequestTypesResponse {
    pagination: Pagination;
    data: RequestType[];
}
export interface ResetPassword {
    token?: string;
    new_password?: string;
}
export interface ResponseBase {
    pagination: Pagination;
}
export interface Result {
    id?: {};
    messages?: ResultMessage[];
    inner_exception?: string;
}
export interface ResultAddOrderProduct {
    card_product?: OrderProductCard;
    voucher_product?: OrderProductVoucher;
}
export interface ResultMessage {
    code?: number;
    message?: string;
    type?: "error" | "warning" | "info";
}
export interface Role {
    /**
     * example:
     * 123
     */
    id: number;
    /**
     * example:
     * Name 123
     */
    name: string;
}
export interface RolesResponse {
    pagination: Pagination;
    data: Role[];
}
export interface SalesManager {
    /**
     * example:
     * Title 123
     */
    title?: string;
    /**
     * example:
     * Jan
     */
    first_name?: string;
    /**
     * example:
     * Novak
     */
    last_name?: string;
    /**
     * example:
     * novak@email.cz
     */
    email?: string;
    /**
     * example:
     * +420 777 777 777
     */
    phone?: string;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    image_id?: string;
}
export interface Scope {
    /**
     * example:
     * 123
     */
    id: number;
    /**
     * example:
     * Name 123
     */
    name: string;
}
export interface SendAmount {
    /**
     * example:
     * 1.5
     */
    amount: number;
    /**
     * Id of recipient(from back side of the recipient card or from qr code).
     * example:
     * 2301
     */
    recipient_holder_id: number;
}
export interface SendAmountResult {
    /**
     * example:
     * Peter Novak
     */
    recipient_name?: string;
}
export interface SidebarItem {
    name?: string;
    amount?: number;
    highlight?: boolean;
}
export interface Text {
    /**
     * example:
     * Titulek
     */
    sk?: string;
    /**
     * example:
     * Title
     */
    en?: string;
}
export interface TokenRequest {
    client_id?: string;
    client_secret?: string;
    scope?: string;
    username?: string;
    password?: string;
    grant_type?: string;
    /**
     * use only for refresh token
     */
    refresh_token?: string;
}
export interface Transaction {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    id: string;
    merchant?: Merchant;
    transaction_type?: TransactionType;
    transaction_group_type?: TransactionGroupType;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    card_id?: string;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    affiliate_id?: string;
    /**
     * example:
     * 2018-02-06 12:00
     */
    date_date?: string;
    /**
     * example:
     * 1.5
     */
    amount?: number;
    terminal_id?: string;
    currency?: Currency;
    other_holderid?: number;
    refuse_reason?: string;
    /**
     * example:
     * 1.5
     */
    amount_abs?: number;
    main_description?: string;
    additional_description?: string;
}
export interface TransactionGroupType {
    /**
     * example:
     * 123
     */
    id: number;
    /**
     * example:
     * Name 123
     */
    name: string;
    color?: string;
}
export interface TransactionType {
    /**
     * example:
     * 123
     */
    id: number;
    /**
     * example:
     * Name 123
     */
    name: string;
    code?: string;
}
export interface TransactionTypesResponse {
    pagination: Pagination;
    data: TransactionType[];
}
export interface TransactionsResponse {
    pagination: Pagination;
    data: Transaction[];
}
export interface User {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    id: string;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    user_access_delivery_address_id?: string;
    /**
     * example:
     * Name 123
     */
    name?: string;
    /**
     * example:
     * Name 123
     */
    work_position?: string;
    /**
     * example:
     * novak@email.cz
     */
    email?: string;
    /**
     * example:
     * +420 777 777 777
     */
    phone?: string;
    user_accesses?: UserAccess[];
}
export interface UserAccess {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    id: string;
    /**
     * example:
     * Name 123
     */
    name: string;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    user_id: string;
    /**
     * example:
     * 123
     */
    role_id: number;
    role?: Role;
    /**
     * example:
     * false
     */
    master: boolean;
    /**
     * example:
     * 123
     */
    scope: number;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    scope_object_id: string;
    /**
     * example:
     * Name 123
     */
    subject_name: string;
    /**
     * example:
     * 2018-02-06 12:00
     */
    readonly last_date_of_login?: string;
}
export interface UserAccessesResponse {
    pagination: Pagination;
    data: UserAccess[];
}
export interface UsersResponse {
    pagination: Pagination;
    data: User[];
}
export interface VersionInfo {
    /**
     * example:
     * 1.1.9
     */
    version?: string;
    /**
     * example:
     * false
     */
    app_mobile?: boolean;
}
export interface VoucherItem {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    delivery_address_id?: string;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    department_id?: string;
    /**
     * example:
     * 1
     */
    packaging_count?: number;
    values: VoucherValueItem[];
    /**
     * example:
     * 123e4567
     */
    uid?: string;
}
export interface VoucherValueItem {
    /**
     * example:
     * 12
     */
    voucher_count: number;
    /**
     * example:
     * 145
     */
    voucher_value: number;
    /**
     * example:
     * 123e4567
     */
    uid?: string;
}
export interface Website {
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    id: string;
    /**
     * example:
     * 123
     */
    website_type_id: number;
    /**
     * example:
     * 123e4567-e89b-12d3-a456-426655440000
     */
    merchant_id: string;
    /**
     * example:
     * www.xyz.com
     */
    url: string;
}
export interface WebsiteType {
    /**
     * example:
     * 123
     */
    id: number;
    /**
     * example:
     * Name 123
     */
    name: string;
}
export interface WebsiteTypesResponse {
    pagination: Pagination;
    data: WebsiteType[];
}
