import { AxiosInstance, AxiosRequestConfig } from 'axios';
import { ClientsResponse, EmployeesResponse, EmployeeDetail, Employee, EmployeeNotificationsResponse, EmployeeNotification, ClientDetail, BranchesResponse, Branch, DeliveryAddressesResponse, File, DeliveryAddress, Department, DepartmentsResponse, Result, EmployeesBulk, ClientsRegistration, CardsResponse, UsersResponse, User, ClientProductsResponse, ClientProduct, Dashboard, ResponseBase, AdministratorsResponse, Administrator, ClientsCheck } from '../__generated__/types';
declare type DocumentsResponse = ResponseBase & {
    data: Document[];
};
export declare class ClientsApi {
    api: AxiosInstance;
    constructor(api?: AxiosInstance);
    getClients(config?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<ClientsResponse>>;
    getClient(clientId: string, config?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<ClientDetail>>;
    getEmployees(clientId: string, config?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<EmployeesResponse>>;
    getEmployee(clientId: string, employeeId: string, config?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<EmployeeDetail>>;
    patchEmployee(clientId: string, employeeId: string, data: Partial<Employee>, config?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<any>>;
    putEmployee(clientId: string, employeeId: string, data: any, config?: AxiosRequestConfig): Promise<import("axios").AxiosResponse<any>>;
    getEmployeeNotifications(clientId: string, employeeId: string, config?: AxiosRequestConfig): import("axios").AxiosPromise<EmployeeNotificationsResponse>;
    putEmployeeNotification(clientId: string, employeeId: string, notificationId: string, data: EmployeeNotification, config?: AxiosRequestConfig): import("axios").AxiosPromise<any>;
    postClientEmployeeNotifications(clientId: string, employeeId: string, data: EmployeeNotification[], config?: AxiosRequestConfig): import("axios").AxiosPromise<any>;
    getBranches(clientId: string, config?: AxiosRequestConfig): import("axios").AxiosPromise<BranchesResponse>;
    getBranch(clientId: string, branchId: string, config?: AxiosRequestConfig): import("axios").AxiosPromise<Branch>;
    getDeliveryAddresses(clientId: string, branchId: string, config?: AxiosRequestConfig): import("axios").AxiosPromise<DeliveryAddressesResponse>;
    getDeliveryAddress(clientId: string, branchId: string, deliverAddressId: string, config?: AxiosRequestConfig): import("axios").AxiosPromise<DeliveryAddress>;
    deleteDeliveryAddress(clientId: string, branchId: string, deliveryAddressId: string, config?: AxiosRequestConfig): import("axios").AxiosPromise<any>;
    putDeliveryAddress(clientId: string, branchId: string, deliveryAddressId: string, body: DeliveryAddress, config?: AxiosRequestConfig): import("axios").AxiosPromise<any>;
    patchDeliveryAddress(clientId: string, branchId: string, deliveryAddressId: string, body: Partial<DeliveryAddress>, config?: AxiosRequestConfig): import("axios").AxiosPromise<Result>;
    getDeliveryAddressesTowns(clientId: string, config?: AxiosRequestConfig): import("axios").AxiosPromise<string[]>;
    postImportFromTemplateClientDeliveryAddresses(clientId: string, branchId: string, body: File, config?: AxiosRequestConfig): import("axios").AxiosPromise<any>;
    getDepartments(clientId: string, config?: AxiosRequestConfig): import("axios").AxiosPromise<DepartmentsResponse>;
    getDepartment(clientId: string, departmentId: string, config?: AxiosRequestConfig): import("axios").AxiosPromise<Department>;
    putDepartment(clientId: string, departmentId: string, body: Department, config?: AxiosRequestConfig): import("axios").AxiosPromise<Result>;
    patchDepartment(clientId: string, departmentId: string, body: Partial<Department>, config?: AxiosRequestConfig): import("axios").AxiosPromise<Result>;
    deleteDepartment(clientId: string, departmentId: string, config?: AxiosRequestConfig): import("axios").AxiosPromise<any>;
    postClientEmployeeBulk(clientId: string, data: EmployeesBulk, config?: AxiosRequestConfig): import("axios").AxiosPromise<Result>;
    postClientRegistration(data: ClientsRegistration, config?: AxiosRequestConfig): import("axios").AxiosPromise<Result>;
    getCards(clientId: string, config?: AxiosRequestConfig): import("axios").AxiosPromise<CardsResponse>;
    getUsers(clientId: string, config?: AxiosRequestConfig): import("axios").AxiosPromise<UsersResponse>;
    putUser(clientId: string, userId: string, data: User, config?: AxiosRequestConfig): import("axios").AxiosPromise<Result>;
    deleteUser(clientId: string, userId: string, config?: AxiosRequestConfig): import("axios").AxiosPromise<any>;
    getNotifications(clientId: string, config?: AxiosRequestConfig): import("axios").AxiosPromise<any>;
    postNotifications(clientId: string, body: any, config?: AxiosRequestConfig): import("axios").AxiosPromise<Result>;
    patchClient(clientId: string, data: Partial<ClientDetail>, config?: AxiosRequestConfig): import("axios").AxiosPromise<Result>;
    getProducts(clientId: string, config?: AxiosRequestConfig): import("axios").AxiosPromise<ClientProductsResponse>;
    postProduct(clientId: string, productId: string, data: Partial<ClientProduct>, config?: AxiosRequestConfig): import("axios").AxiosPromise<Result>;
    postEmployeesImport(clientId: string, data: File, config?: AxiosRequestConfig): import("axios").AxiosPromise<Result>;
    getDashboard(clientId: string, config?: AxiosRequestConfig): import("axios").AxiosPromise<Dashboard>;
    getDocuments(clientId: string, config?: AxiosRequestConfig): import("axios").AxiosPromise<DocumentsResponse>;
    getDocument(clientId: string, documentId: string, config?: AxiosRequestConfig): import("axios").AxiosPromise<Blob>;
    getAdministrators(clientId: string, config?: AxiosRequestConfig): import("axios").AxiosPromise<AdministratorsResponse>;
    getAdministrator(clientId: string, administratorId: string, config?: AxiosRequestConfig): import("axios").AxiosPromise<Administrator>;
    putAdministrator(clientId: string, administratorId: string, body: Partial<Administrator>, config?: AxiosRequestConfig): import("axios").AxiosPromise<Result>;
    deleteAdministrator(clientId: string, administratorId: string, config?: AxiosRequestConfig): import("axios").AxiosPromise<any>;
    /**
     * use with searchparams `registration_identification` and `tax_identification`
     */
    resendPromo(config: AxiosRequestConfig): import("axios").AxiosPromise<Result>;
    /**
     * use with searchparams `registration_identification` and `tax_identification`
     */
    checkClient(config: AxiosRequestConfig): import("axios").AxiosPromise<ClientsCheck>;
    /**
     * use with searchparams `registration_identification` and `tax_identification` and `promo_code`
     */
    verifyPromo(config: AxiosRequestConfig): import("axios").AxiosPromise<Result>;
}
export {};
